@@ -338,11 +338,27 @@ namespace funcopt
         /*!
             Creates a new landscape with a given fitness function.
         */
-        function_landscape(t_function * a_functions)
-          : m_function(a_functions)
+        function_landscape(t_function * a_function, listener & a_listener)
+          : landscape<function_solution>(a_listener),
+            m_function(a_function)
         {
             // nada
         }
+        
+        //! Copy constructor
+        function_landscape(const function_landscape & a_source)
+          : landscape<function_solution>(a_source),
+            m_function(a_source.m_function)
+        {
+            // nada
+        }
+
+        //! Assignment
+        function_landscape & operator = (const function_landscape & a_source)
+        {
+            landscape<function_solution>::operator = (a_source);
+            m_function = a_source.m_function;
+        }
 
         //! Virtual destructor
         /*!
@@ -358,10 +374,9 @@ namespace funcopt
             Tests a single chromosome for fitness by calling the fitness function provided
             in the constructor.
             \param a_organism - The organism to be tested by the landscape.
-            \param a_show - Ignored
             \return Computed fitness for this organism
         */
-        virtual double test(function_solution & a_organism, bool a_show) const
+        virtual double test(function_solution & a_organism, bool a_verbose = false) const
         {
             a_organism.fitness() = m_function(a_organism.genes());
             return a_organism.fitness();
@@ -399,16 +414,30 @@ namespace funcopt
     */
     class function_reporter : public reporter<function_solution, function_landscape>
     {
-    public:
-        //! Say something about a population
-        /*!
-            Reports the genes and fitness for the best solution.
-            \param a_populations - Population for reporting
-            \param a_iteration - Iteration count for this report
-            \param a_fitness - Not used in function_reporter; ignored
-            \param a_finished - Not used in function_reporter; ignored
-        */
-        virtual bool report(const vector< vector<function_solution> > & a_population, size_t a_iteration, double & a_fitness, bool a_finished = false);
+        public:
+            //! Constructor
+            /*!
+                Creates a new reporter object
+                \param a_listener - a listener for events
+            */
+            function_reporter()
+              : reporter<function_solution, function_landscape>(m_listener)
+            {
+                // nada
+            }
+                
+            //! Say something about a population
+            /*!
+                Reports the genes and fitness for the best solution.
+                \param a_populations - Population for reporting
+                \param a_iteration - Iteration count for this report
+                \param a_fitness - Not used in function_reporter; ignored
+                \param a_finished - Not used in function_reporter; ignored
+            */
+            virtual bool report(const vector< vector<function_solution> > & a_population, size_t a_iteration, double & a_fitness, bool a_finished = false);
+
+        protected:
+            listener_stdout m_listener;
     };
 
     //! A generic function optimizer
@@ -425,22 +454,28 @@ namespace funcopt
         // a function type
         typedef function_solution t_init();
 
-        // create objects that define this population
+        // objects that define the characteristics of the genetic algorithm
         function_mutator                    m_mutator;
         function_reproducer                 m_reproducer;
         null_scaler<function_solution>      m_scaler;
         null_migrator<function_solution>    m_migrator;
         elitism_selector<function_solution> m_selector;
         function_reporter                   m_reporter;
+        
+        // the evocosm binds it all together; kinda like the "one ring" Bilbo found!
+        evocosm<function_solution,function_landscape> * m_evocosm;
+        
+        // number of iterations to run
+        const size_t                        m_iterations;
+        
+        // a function that provides initialized, random solutions
         t_init *                            m_init;
+        
+        // the function to be optimized
         t_function *                        m_function;
 
-        // the evocosm that binds it all together; kinda like the "one ring" Bilbo
-        // found!
-        evocosm<function_solution,function_landscape> * m_evocosm;
-
-        // number of iterations to run
-        const size_t m_iterations;
+        // null listener
+        null_listener                       m_listener;
 
     public:
         //! Constructor
@@ -462,7 +497,7 @@ namespace funcopt
         /*!
             Cleans up resources by removing allocated objects.
         */
-        ~function_optimizer()
+        virtual ~function_optimizer()
         {
             delete m_evocosm;
         }
