@@ -1,11 +1,11 @@
 //---------------------------------------------------------------------
-//  Algorithmic Conjurings @ http://www.coyotlgulch.com
+//  Algorithmic Conjurings @ http://www.coyotegulch.com
 //  Evocosm -- An Object-Oriented Framework for Evolutionary Algorithms
 //
 //  fuzzy_machine.h
 //---------------------------------------------------------------------
 //
-//  Copyright 1996-2004 Scott Robert Ladd
+//  Copyright 1996, 1999, 2002, 2003, 2004, 2005 Scott Robert Ladd
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -133,14 +133,14 @@ namespace libevocosm
             \param a_parent1 - The first parent organism
             \param a_parent2 - The second parent organism
         */
-        fuzzy_machine(const fuzzy_machine & a_parent1, const fuzzy_machine & a_parent2);
+        fuzzy_machine(const fuzzy_machine<InSize,OutSize> & a_parent1, const fuzzy_machine<InSize,OutSize> & a_parent2);
 
         //! Copy constructor
         /*!
             Creates a new fuzzy_machine identical to an existing one.
             \param a_source - Object to be copied
         */
-        fuzzy_machine(const fuzzy_machine & a_source);
+        fuzzy_machine(const fuzzy_machine<InSize,OutSize> & a_source);
 
         //! Virtual destructor
         /*!
@@ -155,7 +155,7 @@ namespace libevocosm
             \param a_source - Object to be copied
             \return Reference to target object
         */
-        fuzzy_machine & operator = (const fuzzy_machine & a_source);
+        fuzzy_machine & operator = (const fuzzy_machine<InSize,OutSize> & a_source);
 
         //!  Mutation
         /*!
@@ -265,7 +265,7 @@ namespace libevocosm
         void release();
 
         // deep copy
-        void deep_copy(const fuzzy_machine & a_source);
+        void deep_copy(const fuzzy_machine<InSize,OutSize> & a_source);
 
     protected:
         //!  State table (the machine definition)
