@@ -1,11 +1,11 @@
 //---------------------------------------------------------------------
-//  Algorithmic Conjurings @ http://www.coyotlgulch.com
+//  Algorithmic Conjurings @ http://www.coyotegulch.com
 //  Evocosm -- An Object-Oriented Framework for Evolutionary Algorithms
 //
 //  simple_fsm.h
 //---------------------------------------------------------------------
 //
-//  Copyright 1996-2004 Scott Robert Ladd
+//  Copyright 1996, 1999, 2002, 2003, 2004, 2005 Scott Robert Ladd
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -83,14 +83,14 @@ namespace libevocosm
             \param a_parent1 - The first parent organism
             \param a_parent2 - The second parent organism
         */
-        simple_fsm(const simple_fsm & a_parent1, const simple_fsm & a_parent2);
+        simple_fsm(const simple_fsm<InSize,OutSize> & a_parent1, const simple_fsm<InSize,OutSize> & a_parent2);
 
         //! Copy constructor
         /*!
             Creates a new simple_fsm identical to an existing one.
             \param a_source - Object to be copied
         */
-        simple_fsm(const simple_fsm & a_source);
+        simple_fsm(const simple_fsm<InSize,OutSize> & a_source);
 
         //! Virtual destructor
         /*!
@@ -105,7 +105,7 @@ namespace libevocosm
             \param a_source - Object to be copied
             \return A reference to the target object
         */
-        simple_fsm & operator = (const simple_fsm & a_source);
+        simple_fsm & operator = (const simple_fsm<InSize,OutSize> & a_source);
 
         //!  Mutation
         /*!
@@ -195,7 +195,7 @@ namespace libevocosm
         void release();
 
         // deep copy
-        void deep_copy(const simple_fsm & a_source);
+        void deep_copy(const simple_fsm<InSize,OutSize> & a_source);
 
     protected:
         //!  State table (the machine definition)
